#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'lib/Inca/Suite/SeriesConfig.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 123 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;
  lives_ok { new Inca::Suite::SeriesConfig() } 'object created';


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 200 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;
  my $sc = new Inca::Suite::SeriesConfig(); 
  lives_ok { $sc->addArgument( 'host', 'cuzco.sdsc.edu' ) } 
           'add argument succeeds';
  dies_ok { $sc->addArgument( '!h5', 'blah' ) } 'add with bad name';
  lives_ok { $sc->addArgument( 'help' ) } 'add with just name';
  $sc->addArgument( 'file', 'big.dat' );
  $sc->addArgument( 'compiler', 'gcc' );
  $sc->addArgument( 'host', 'machu.sdsc.edu' );
  $sc->addArgument( 'file', 'huge.dat' );
  $sc->addArgument( 'compiler', 'xlc' );
  $sc->addArgument( 'phrase', 'hi there' );
  $sc->addArgument( 'host', 'pichu.sdsc.edu' );
  my $cmdline = $sc->getArgumentsAsCmdLine();
  my $verify = '-host="cuzco.sdsc.edu" -help -file="big.dat" -compiler="gcc" -host="machu.sdsc.edu" -file="huge.dat" -compiler="xlc" -phrase="hi there" -host="pichu.sdsc.edu"';
  is( $cmdline, $verify, "getArgsAsCmdline() succeeded" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 247 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc1 = new Inca::Suite::SeriesConfig();
  my $sc2 = new Inca::Suite::SeriesConfig();
  $sc1->setPath( "/tmp/reporter1" );
  $sc2->setPath( "/tmp/reporter2" );
  ok( ! $sc1->equals($sc2), "not equals (path)" );
  $sc2->setPath( "/tmp/reporter1" );
  ok( $sc1->equals($sc2), "equals (path)" );
  $sc1->setName( "reporter1" );
  $sc2->setName( "sc2" );
  ok( ! $sc1->equals($sc2), "not equals (name)" );
  $sc2->setName( "reporter1" );
  ok( $sc1->equals($sc2), "equals (name)" );
  $sc1->setVersion( "1" );
  $sc2->setVersion( "2" );
  ok( ! $sc1->equals($sc2), "not equals (version)" );
  $sc2->setVersion( "1" );
  ok( $sc1->equals($sc2), "equals (version)" );
  $sc1->setContext( "http://inca.sdsc.edu/reporterA" );
  ok( ! $sc1->equals($sc2), "not equals (context)" );
  $sc2->setContext( "http://inca.sdsc.edu/reporterA" );
  ok( $sc1->equals($sc2), "equals (context)" );
  $sc2->setNiced( 1 );
  ok( ! $sc1->equals($sc2), "not equals (niced)" );
  $sc1->setNiced( 1 );
  ok( $sc1->equals($sc2), "equals (niced)" );
  my $limits = { 'wallClockTime' => '30',
                 'cpuTime' => '40',
                 'memory' => '50' };
  $sc1->setLimits( $limits );
  ok( ! $sc1->equals($sc2), "not equals (limits)" );
  $sc2->setLimits( { 'wallClockTime' => '30' } );
  ok( ! $sc1->equals($sc2), "not equals (limits2)" );
  $sc2->setLimits( $limits );
  ok( $sc1->equals($sc2), "equals (limits)" );
  $sc1->addArgument( 'file', 'big.dat' );
  ok( ! $sc1->equals($sc2), "not equals (args)" );
  $sc2->addArgument( 'compiler', 'gcc' );
  ok( ! $sc1->equals($sc2), "not equals (args2)" );
  $sc1->addArgument( 'host', 'machu.sdsc.edu' );
  $sc2->addArgument( 'file', 'huge.dat' );
  ok( ! $sc1->equals($sc2), "not equals (args3)" );
  $sc1->addArgument( 'phrase', 'hi there' );
  ok( ! $sc1->equals($sc2), "not equals (args4)" );
  $sc2->{args} = [];
  $sc2->addArgument( 'file', 'big.dat' );
  $sc2->addArgument( 'host', 'machu.sdsc.edu' );
  $sc2->addArgument( 'phrase', 'hi dude' );
  ok( ! $sc1->equals($sc2), "not equals (args5)" );
  $sc2->{args} = [];
  $sc2->addArgument( 'file', 'big.dat' );
  $sc2->addArgument( 'host', 'machu.sdsc.edu' );
  $sc2->addArgument( 'phrase', 'hi there' );
  ok( $sc1->equals($sc2), "equals (args)" );
  my $sp = new Inca::Suite::StoragePolicy();
  $sp->addDepots( "cuzco.sdsc.edu:8234" );
  $sc1->setStoragePolicy( $sp );
  ok( ! $sc1->equals($sc2), "not equals (sp)" );
  $sc2->setStoragePolicy( $sp );
  ok( $sc1->equals($sc2), "equals (sp)" );



    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 360 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getAction(), undef, 'returns group action for undef' );

  my $sc_desc = {
    'action' => 'add',
    'schedule' => undef,
    'series' => {
         'name' => 'cluster.compiler.gcc.version',
         'version' => '1',
         'context' => 'file:///usr/local/bin/cluster.compiler.gcc.version',
         'limits' => { 'wallClockTime' => '300' },
    }
  }; 
  is( $sc->read( $sc_desc ), 1, "read good config without error" );
  is( $sc->getName(), "cluster.compiler.gcc.version", 
      "read good group and found name" );

  $sc->read( $sc_desc ); 
  is( $sc->getAction(), 'add', 'returns group action' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 412 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;
  my $sc = new Inca::Suite::SeriesConfig(); 
  $sc->addArgument( 'file', 'big.dat' );
  my @args = $sc->getArgumentsAsCmdLine();
  ok( eq_array( \@args, [ '-file="big.dat"' ] ),
      'getArgumentsAsCmdLine returns array of one element' );
  $sc->addArgument( 'compiler', 'gcc' );
  @args = $sc->getArgumentsAsCmdLine();
  ok( eq_array( \@args, [ '-file="big.dat"', '-compiler="gcc"' ] ),
      'getArgumentsAsCmdLine returns array of 2 element' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 449 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;
  my $sc = new Inca::Suite::SeriesConfig(); 
  $sc->getArgumentsFromCmdLine( 
    '-verbose="1"', '-log="system"', '-help="no"', '-blah="hi there"'
  );
  is( $sc->getArgumentsAsCmdLine(),
      '-verbose="1" -log="system" -help="no" -blah="hi there"',
      'getArgumentsFromCmdLine works' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 630 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getSchedulerArgs(), undef, 
      "undefined scheduler args from constructor" );
  $sc->setSchedulerArgs( { repeat => '60m' } );
  ok( eq_hash( $sc->getSchedulerArgs(), { repeat => '60m' }),
      'set/getSchedulerArgs works' );
  my $sc_desc = { 
    'action' => 'add', 
    'schedule' => { 'dumbcron' => { repeat => '60s' } },
    'series' => {
      'name' => "name",
      'version' => 'version',
      'context' => 'context'
    }
  };
  $sc->read( $sc_desc );
  ok( eq_hash( $sc->getSchedulerArgs(), { repeat => '60s' }),
      'scheduler args set from read' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 678 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $sc_desc = { 
    'action' => 'add', 
    'schedule' => undef,
    'series' => {
      'name' => 'name',
      'version' => 'version',
      'context' => 'context'
    }
   };
  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getSchedulerName(), undef, 
      "undefined scheduler name from constructor" );
  $sc->setSchedulerName( "bogus" );
  is( $sc->getSchedulerName(), "bogus", "set/getSchedulerName worked" );
  $sc->read( $sc_desc );
  is( $sc->getSchedulerName(), 'sequential', "scheduler set from read" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 771 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasArguments(), 'hasArguments for false' );
  $sc->addArgument( "arg", "value" );
  ok( $sc->hasArguments(), 'hasArguments for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 805 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasContext(), 'hasContext for false' );
  $sc->setContext( '@@; echo $?' );
  ok( $sc->hasContext(), 'hasContext for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 839 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasLimits(), 'hasLimits for false' );
  my $limits = { "wallClockTime" => 30 };
  $sc->setLimits( $limits );
  ok( $sc->hasLimits(), 'hasLimits for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 873 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasNiced(), 'hasNiced for false' );
  $sc->setNiced( 1 );
  ok( $sc->hasNiced(), 'hasNiced for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 907 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasPath(), 'hasPath for false' );
  $sc->setPath( '/tmp/reporterA' );
  ok( $sc->hasPath(), 'hasPath for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 941 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasProxyContact(), 'hasProxyContact for false' );
  $sc->setProxyContact( "incas://localhost:3234" );
  ok( $sc->hasProxyContact(), 'hasProxy for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 975 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;

  my $sc = new Inca::Suite::SeriesConfig();
  ok( ! $sc->hasScheduler(), 'hasScheduler for false' );
  $sc->setSchedulerName( "sequential" );
  ok( $sc->hasScheduler(), 'hasScheduler for true' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1016 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;
  use Data::Dumper;

  Inca::Logger->screen_init( "ERROR" );

  my $sc = new Inca::Suite::SeriesConfig();

  # good one
  my $scHash = {
    'resourceSetName' => 'localhost',
    'action' => 'add',
    'schedule' => undef,
    'series' => {
      'limits' => {
        'wallClockTime' => 300 
      },  
      'version' => '1',
      'context' => 'PATH=./bin:${PATH}; cluster.compiler.gcc.version -verbose="0" -log=""; echo $?',
      'args' => { arg => [ { name => 'verbose', value => 0 },
                           { name => 'log', value => undef } ] },
      'name' => 'cluster.compiler.gcc.version',
      'niced' => 0,
    }
  };
  is( $sc->read($scHash), 1, "read good config without error" );
  is( $sc->getName(), 'cluster.compiler.gcc.version', 'name set from read' );
  is( $sc->getVersion(), '1', 'version set from read' );
  is( $sc->getAction(), 'add', 'action set from read' );
  is($sc->getArgumentsAsCmdLine(), '-verbose="0" -log=""','args set from read');
  is( $sc->getNiced(), 0, 'niced set from read');
  isa_ok( $sc->getLimits(), "Inca::Process::Usage", 
          'limits set from read');
  is( $sc->getContext(), 'PATH=./bin:${PATH}; cluster.compiler.gcc.version -verbose="0" -log=""; echo $?', 'context set from read' );

  # bad one -- no name
  my $sc_noname = eval Dumper $scHash;
  $sc_noname->{series}->{name} = undef;
  is( $sc->read($sc_noname), 0, "read failed with no name" );
  ok( $_STDERR_ =~ /no name located/, "no name error printed" );

  # bad one -- no version
  my $sc_noversion = eval Dumper $scHash;
  $sc_noversion->{series}->{version} = undef;
  is( $sc->read($sc_noversion), 0, "read failed with no version" );
  ok( $_STDERR_ =~ /no version located/, "no version error printed" );

  # bad one -- no action
  my $sc_noaction = eval Dumper $scHash;
  $sc_noaction->{action} = undef;
  is( $sc->read($sc_noaction), 0, "read failed with no action" );
  ok( $_STDERR_ =~ /no action located/, "no action error printed" );

  # bad one -- no scheduler
  my $sc_nosched = eval Dumper $scHash;
  delete $sc_nosched->{schedule}; 
  is( $sc->read($sc_nosched), 0, "read failed with no scheduler" );
  ok( $_STDERR_ =~ /No schedule found/, "no schedule error printed" );

  # bad one -- more than one scheduler
  my $sc_mulsched = eval Dumper $scHash;
  $sc_mulsched->{schedule} = {
       'sequential' => undef,
       'cron' => undef };
  is( $sc->read($sc_mulsched), 0, "read failed with multiple scheduler" );
  ok( $_STDERR_ =~ /multiple schedules/, "multiple schedule error printed" );

  # bad one -- bad sched obj
  my $sc_badsched = eval Dumper $scHash;
  $sc_badsched->{schedule} = 5;
  is( $sc->read($sc_badsched), 0, "read failed with bad scheduler" );
  ok( $_STDERR_ =~ /hash not found/, "bad schedule error printed" );

  # bad one -- no context
  my $sc_nocontext =  eval Dumper $scHash;
  $sc_nocontext->{series}->{context} = undef;
  is( $sc->read($sc_nocontext), 0, "read failed with no context" );
  ok( $_STDERR_ =~ /no context located/, "no context error printed" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1200 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $action1 = "add";
  my $action2 = "delete";
  my $sc = new Inca::Suite::SeriesConfig();
  is ( $sc->getAction(), undef, 'get action was undef from constructor' );
  $sc = new Inca::Suite::SeriesConfig( action => $action1 ); 
  is ( $sc->getAction(), $action1, 'set action worked from constructor' );
  $sc->setAction( $action2 );
  is ( $sc->getAction(), $action2, 'set/getAction worked' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1248 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getContext(), undef, 'context undef after constructor' );
  $sc = new Inca::Suite::SeriesConfig( 
    context => 'http://inca.sdsc.edu/reporterA' 
  );
  is( $sc->getContext(), 'http://inca.sdsc.edu/reporterA', 
      'context set after constructor' );
  $sc->setContext( 'http://inca.sdsc.edu/reporterB' );
  is( $sc->getContext(), 'http://inca.sdsc.edu/reporterB', 
      'set/getContext works' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1297 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Inca::Process::Usage;
  use Test::Exception;

  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getLimits(), undef, 'limits undefined after constructor' );

  my $limits = { 'wallClockTime' => '30',
                 'cpuTime' => '40',
                 'memory' => '50' };
  $sc->setLimits( $limits );
  isa_ok( $sc->getLimits(), "Inca::Process::Usage", 
          'set/getLimits worked' );
  is( $sc->getLimits->getWallClockTime(), 30, 'wall clock read correctly' );
  is( $sc->getLimits->getCpuTime(), 40, 'cpu time read correctly' );
  is( $sc->getLimits->getMemory(), 50, 'memory read correctly' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1357 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $name1 = "reporter1";
  my $name2 = "reporter2";
  my $sc = new Inca::Suite::SeriesConfig();
  is ( $sc->getName(), undef, 'get name was undef from constructor' );
  $sc = new Inca::Suite::SeriesConfig( name => $name1 ); 
  is ( $sc->getName(), $name1, 'set name worked from constructor' );
  $sc->setName( $name2 );
  is ( $sc->getName(), $name2, 'set/getName worked' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1404 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $sc = new Inca::Suite::SeriesConfig();
  is( $sc->getNiced(), undef, 'niced undef after constructor' );
  $sc = new Inca::Suite::SeriesConfig( niced => 0 );
  is( $sc->getNiced(), 0, 'Set niced works from constructor' );
  $sc->setNiced( 1 );
  is( $sc->getNiced(), 1, 'Set/getNiced works' );
  dies_ok { $sc->setNiced(-10) } 
          'Set niced dies when non-boolean specified as arg';


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1449 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $path1 = "/tmp/reporter1";
  my $path2 = "/tmp/reporter2";
  my $sc = new Inca::Suite::SeriesConfig();
  is ( $sc->getPath(), undef, 'get path was undef from constructor' );
  $sc = new Inca::Suite::SeriesConfig( path => $path1 ); 
  is ( $sc->getPath(), $path1, 'set path worked from constructor' );
  $sc->setPath( $path2 );
  is ( $sc->getPath(), $path2, 'set/getPath worked' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1506 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $uri1 = "incas://localhost:3234";
  my $uri2 = "incas://localhost:3235";
  my $sc = new Inca::Suite::SeriesConfig();
  is ( $sc->getProxyContact(), undef, 
       'get proxy contact was undef from constructor' );
  $sc= new Inca::Suite::SeriesConfig( proxyContact => $uri1 ); 
  is( $sc->getProxyContact(), $uri1, 'set proxy worked from constructor' );
  $sc->setProxyContact( $uri2 );
  is( $sc->getProxyContact(), $uri2, 'set/getProxyContact worked' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1551 lib/Inca/Suite/SeriesConfig.pm

  # see getSchedulerArgs


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1585 lib/Inca/Suite/SeriesConfig.pm

  # see getSchedulerName


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1622 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Inca::Suite::StoragePolicy;
  use Test::Exception;

  my $sp = new Inca::Suite::StoragePolicy();
  my $sc = new Inca::Suite::SeriesConfig( storagePolicy => $sp );
  isa_ok( $sc->getStoragePolicy(), 
          "Inca::Suite::StoragePolicy",
          'set storage policy worked from constructor' );
  my $sp2 = new Inca::Suite::StoragePolicy();
  $sp2->addDepots( "ssl:localhost:6323" );
  $sc->setStoragePolicy( $sp2 );
  is( $sc->getStoragePolicy()->{depots}[0], "ssl:localhost:6323", 
      'set/get storage policy works' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 1670 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  use Test::Exception;

  my $version1 = "1";
  my $version2 = "2";
  my $sc = new Inca::Suite::SeriesConfig();
  is ($sc->getVersion(), undef, 'get version was undef from constructor');
  $sc = new Inca::Suite::SeriesConfig( version => $version1 ); 
  is ( $sc->getVersion(), $version1, 'set version worked from constructor' );
  $sc->setVersion( $version2 );
  is ( $sc->getVersion(), $version2 , 'set/getVersion worked' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
eval q{
  my $example = sub {
    local $^W = 0;

#line 12 lib/Inca/Suite/SeriesConfig.pm

  use Inca::Suite::SeriesConfig;
  my $sc = new Inca::Suite::SeriesConfig();
  $sc->read( $parsedXML );
  my $name = $sc->getName();
  my $version  = $sc->getVersion();
  my $args = $sc->getArgumentsAsCmdLine();
  my $niced = $sc->getNiced();
  my $limits = $sc->getLimits();

;

  }
};
is($@, '', "example from line 12");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;

