#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'lib/Inca/Suite.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 82 lib/Inca/Suite.pm

  use Inca::Suite;
  use Test::Exception;
  lives_ok { new Inca::Suite() } 'object created';


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 120 lib/Inca/Suite.pm

  use Inca::Suite;
  use Test::Exception;

  my $suite = new Inca::Suite();
  $suite->read( "t/suite.xml" ); 
  is( $suite->getGuid(), "incas://localhost:6323/testSuite", "got guid" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 153 lib/Inca/Suite.pm

  use Inca::Suite;
  use Test::Exception;

  my $suite = new Inca::Suite();
  $suite->read( "t/suite.xml" ); 
  my @scs = $suite->getSeriesConfigs();
  is( scalar(@scs), 2, "found 2 series configs" );
  isa_ok( $scs[0], "Inca::Suite::SeriesConfig", 
          "series config is a series config" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 209 lib/Inca/Suite.pm

  use Inca::Suite;
  use Test::Exception;

  my $suite = new Inca::Suite();
  my $result;
  $result = $suite->read( "t/suite.xml" ); 
  is( $result, 1, "read on good suite - returns true" );
  is( ($suite->getSeriesConfigs())[0]->getName(),
      "echo_report",
      "read on good suite - found first name" );
  my @files = qw(t/suite_badxml.xml t/suite_noaction.xml t/suite_badconfig.xml);
  for my $file ( @files ) {
    is( $suite->read( $file ), 0, "read on $file - returns false" );
  }


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 292 lib/Inca/Suite.pm

  use Inca::Suite;
  use Inca::ReporterManager::ReporterCache;
  use Test::Exception;
  use Cwd;

  my $suite = new Inca::Suite();
  my $rc = new Inca::ReporterManager::ReporterCache( "t" );
  $suite->read( "t/suite.xml" ); 
  for my $sc ( $suite->getSeriesConfigs() ) {
    is( undef, $sc->getPath(), 'no path set now' );
  }
  my $uri = "incas://localhost:3234";
  $suite->resolveReporters( $rc, $uri );
  my $cwd = getcwd();
  for my $sc ( $suite->getSeriesConfigs() ) {
    ok( defined($sc->getPath()), 'path set now' );
    like( 
      $sc->getPath(), 
      qr/$cwd/, 
      "series config has set path"
    );
    ok( ! $sc->hasProxyContact(), "proxy contact not found" );
  }

  $suite = new Inca::Suite();
  $suite->read( "t/grid_suite.xml" ); 
  $suite->resolveReporters( $rc, $uri );
  for my $sc ( $suite->getSeriesConfigs() ) {
    ok( $sc->hasProxyContact(), "proxy contact found" );
    is( $sc->getProxyContact(), $uri, "proxy contact uri found" );
  }


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
eval q{
  my $example = sub {
    local $^W = 0;

#line 12 lib/Inca/Suite.pm

  use Inca::Suite;
  my $suite = new Inca::Suite();
  $suite->read( "suite.xml" );
  my @scs = $suite->getSeriesConfigs();

;

  }
};
is($@, '', "example from line 12");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;

